[Phpmyadmin-git] [SCM] phpMyAdmin branch, master, updated. RELEASE_3_5_0ALPHA1-10-g02fb282

Marc Delisle lem9 at users.sourceforge.net
Sun Jan 8 13:39:33 CET 2012


The branch, master has been updated
       via  02fb282694b9d4e18915b95c93ec27f50db7f048 (commit)
      from  dcc9b2c71f0141a08a64584e2549fd12d5c60285 (commit)


- Log -----------------------------------------------------------------
commit 02fb282694b9d4e18915b95c93ec27f50db7f048
Author: Marc Delisle <marc at infomarc.info>
Date:   Sun Jan 8 07:39:20 2012 -0500

    Clarify parameter name

-----------------------------------------------------------------------

Summary of changes:
 libraries/tbl_select.lib.php |   13 ++++++-------
 1 files changed, 6 insertions(+), 7 deletions(-)

diff --git a/libraries/tbl_select.lib.php b/libraries/tbl_select.lib.php
index f660ba6..967f39c 100644
--- a/libraries/tbl_select.lib.php
+++ b/libraries/tbl_select.lib.php
@@ -129,13 +129,12 @@ function PMA_tbl_getSubTabs()
  * @param int    $foreignMaxLimit Max limit of displaying foreign elements
  * @param array  $fields          Array of search criteria inputs
  * @param bool   $in_fbs          Whether we are in 'function based search'
  * @param bool   $in_edit         Whether in search mode
  *                                    or edit mode (used for zoom search)
  *
  * @return string HTML content for viewing foreing data and elements
  * for search criteria input.
  */
-function PMA_getForeignFields_Values($foreigners, $foreignData, $field, $tbl_fields_type, $i, $db, $table, $titles, $foreignMaxLimit, $fields, $in_fbs = false, $in_edit = false)
+function PMA_getForeignFields_Values($foreigners, $foreignData, $field, $tbl_fields_type, $i, $db, $table, $titles, $foreignMaxLimit, $fields, $in_fbs = false, $in_zoom_search_edit = false)
 {
     $str = '';
     if ($foreigners && isset($foreigners[$field]) && is_array($foreignData['disp_row'])) {
@@ -168,7 +167,7 @@ function PMA_getForeignFields_Values($foreigners, $foreignData, $field, $tbl_fie
 <a target="_blank" onclick="window.open(this.href, 'foreigners', 'width=640,height=240,scrollbars=yes'); return false" href="browse_foreigners.php?
 EOT;
     $str .= '' . PMA_generate_common_url($db, $table) .  '&field=' . urlencode($field) . '&fieldkey=' . $i . '"';
-    if ($in_edit) {
+    if ($in_zoom_search_edit) {
         $str .= ' class="browse_foreign"';
     }
     $str .= '>' . str_replace("'", "\'", $titles['Browse']) . '</a>';
@@ -189,7 +188,7 @@ EOT;
         }
 
     } elseif (strncasecmp($tbl_fields_type[$i], 'enum', 4) == 0
-        || (strncasecmp($tbl_fields_type[$i], 'set', 3) == 0 && $in_edit)
+        || (strncasecmp($tbl_fields_type[$i], 'set', 3) == 0 && $in_zoom_search_edit)
     ) {
         // e n u m s   a n d   s e t s
 
@@ -202,8 +201,8 @@ EOT;
         $value = explode(', ', str_replace("'", '', substr($tbl_fields_type[$i], 5, -1)));
         $cnt_value = count($value);
 
-        if ((strncasecmp($tbl_fields_type[$i], 'enum', 4) && ! $in_edit)
-            || (strncasecmp($tbl_fields_type[$i], 'set', 3) && $in_edit)
+        if ((strncasecmp($tbl_fields_type[$i], 'enum', 4) && ! $in_zoom_search_edit)
+            || (strncasecmp($tbl_fields_type[$i], 'set', 3) && $in_zoom_search_edit)
         ) {
             $str .= '<select name="fields[' . ($i) . '][]" id="fieldID_' . $i .'">' . "\n";
         } else {
@@ -129,13 +129,12 @@ function PMA_tbl_getSubTabs()
  * @param array  $fields          Array of search criteria inputs
  * @param bool   $in_fbs          Whether we are in 'function based search'
- * @param bool   $in_edit         Whether in search mode
- *                                    or edit mode (used for zoom search)
+ * @param bool   $in_zoom_search_edit  Whether we are in zoom search edit 
  *
  * @return string HTML content for viewing foreing data and elements


hooks/post-receive
-- 
phpMyAdmin




More information about the Git mailing list